/*
** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License Version 2 as
** published by the Free Software Foundation.  You may not use, modify or
** distribute this program under any other version of the GNU General
** Public License.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#include "config.h"             /* From autoconf */
#endif

/* Storage for protocol.map (program search) */

typedef struct _Sagan_Protocol_Map_Program _Sagan_Protocol_Map_Program;
struct _Sagan_Protocol_Map_Program {
    int type;
    int proto;
    int nocase;
    char program[64];
};

/* Storage for protocol.map (message search) */

typedef struct _Sagan_Protocol_Map_Message _Sagan_Protocol_Map_Message;
struct _Sagan_Protocol_Map_Message {
    int type;
    int proto;
    int nocase;
    char search[512];
};

void Load_Protocol_Map( const char * );

